@@ -1,5 +1,5 @@
 package Data::Verifier;
-$Data::Verifier::VERSION = '0.65';
+$Data::Verifier::VERSION = '0.66';
 use Moose;
 
 # ABSTRACT: Profile based data verification with Moose type constraints.
@@ -363,7 +363,7 @@ Data::Verifier - Profile based data verification with Moose type constraints.
 
 =head1 VERSION
 
-version 0.65
+version 0.66
 
 =head1 DESCRIPTION
 
@@ -775,7 +775,7 @@ J. Shirley
 
 Wallace Reis
 
-Mohammad S Anwar
+Mohammad Sajid Anwar
 
 Hernan Lopes
 
@@ -785,7 +785,7 @@ Cory G Watson <gphat@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2023 by Cold Hard Code, LLC.
+This software is copyright (c) 2024 by Cold Hard Code, LLC.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
